CHAR_EXCLAIM = [
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
]

CHAR_AT = [
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x3F\xFF\xFC\x00",
    b"\x00\x3F\xFF\xFC\x00",
    b"\x00\x3F\xFF\xFC\x00",
    b"\x00\x3F\xFF\xFC\x00",
    b"\x00\x3F\xFF\xFC\x00",
    b"\x07\xFE\x00\x7F\xE0",
    b"\x07\xFE\x00\x7F\xE0",
    b"\x07\xFE\x00\x7F\xE0",
    b"\x07\xFE\x00\x7F\xE0",
    b"\x07\xFE\x00\x7F\xE0",
    b"\x07\xFE\x0F\xFF\xE0",
    b"\x07\xFE\x0F\xFF\xE0",
    b"\x07\xFE\x0F\xFF\xE0",
    b"\x07\xFE\x0F\xFF\xE0",
    b"\x07\xFE\x0F\xFF\xE0",
    b"\x07\xFE\x0F\xFC\x00",
    b"\x07\xFE\x0F\xFC\x00",
    b"\x07\xFE\x0F\xFC\x00",
    b"\x07\xFE\x0F\xFC\x00",
    b"\x07\xFE\x0F\xFC\x00",
    b"\x07\xFE\x00\x00\x00",
    b"\x07\xFE\x00\x00\x00",
    b"\x07\xFE\x00\x00\x00",
    b"\x07\xFE\x00\x00\x00",
    b"\x07\xFE\x00\x00\x00",
    b"\x00\x3F\xFF\xFF\xE0",
    b"\x00\x3F\xFF\xFF\xE0",
    b"\x00\x3F\xFF\xFF\xE0",
    b"\x00\x3F\xFF\xFF\xE0",
    b"\x00\x3F\xFF\xFF\xE0",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
]

CHAR_POUND = [
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x3E\x00\x7C\x00",
    b"\x00\x3E\x00\x7C\x00",
    b"\x00\x3E\x00\x7C\x00",
    b"\x00\x3E\x00\x7C\x00",
    b"\x00\x3E\x00\x7C\x00",
    b"\x07\xFF\xFF\xFF\xE0",
    b"\x07\xFF\xFF\xFF\xE0",
    b"\x07\xFF\xFF\xFF\xE0",
    b"\x07\xFF\xFF\xFF\xE0",
    b"\x07\xFF\xFF\xFF\xE0",
    b"\x00\x3E\x00\x7C\x00",
    b"\x00\x3E\x00\x7C\x00",
    b"\x00\x3E\x00\x7C\x00",
    b"\x00\x3E\x00\x7C\x00",
    b"\x00\x3E\x00\x7C\x00",
    b"\x07\xFF\xFF\xFF\xE0",
    b"\x07\xFF\xFF\xFF\xE0",
    b"\x07\xFF\xFF\xFF\xE0",
    b"\x07\xFF\xFF\xFF\xE0",
    b"\x07\xFF\xFF\xFF\xE0",
    b"\x00\x3E\x00\x7C\x00",
    b"\x00\x3E\x00\x7C\x00",
    b"\x00\x3E\x00\x7C\x00",
    b"\x00\x3E\x00\x7C\x00",
    b"\x00\x3E\x00\x7C\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
]

CHAR_DOLLAR = [
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x3F\xFF\xFF\xE0",
    b"\x00\x3F\xFF\xFF\xE0",
    b"\x00\x3F\xFF\xFF\xE0",
    b"\x00\x3F\xFF\xFF\xE0",
    b"\x00\x3F\xFF\xFF\xE0",
    b"\x07\xC0\x00\x00\x00",
    b"\x07\xC0\x00\x00\x00",
    b"\x07\xC0\x00\x00\x00",
    b"\x07\xC0\x00\x00\x00",
    b"\x07\xC0\x00\x00\x00",
    b"\x00\x3F\xFF\xFC\x00",
    b"\x00\x3F\xFF\xFC\x00",
    b"\x00\x3F\xFF\xFC\x00",
    b"\x00\x3F\xFF\xFC\x00",
    b"\x00\x3F\xFF\xFC\x00",
    b"\x00\x00\x00\x03\xE0",
    b"\x00\x00\x00\x03\xE0",
    b"\x00\x00\x00\x03\xE0",
    b"\x00\x00\x00\x03\xE0",
    b"\x00\x00\x00\x03\xE0",
    b"\x07\xFF\xFF\xFC\x00",
    b"\x07\xFF\xFF\xFC\x00",
    b"\x07\xFF\xFF\xFC\x00",
    b"\x07\xFF\xFF\xFC\x00",
    b"\x07\xFF\xFF\xFC\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
]

CHAR_PERCENT = [
    b"\x07\xFE\x00\x03\xE0",
    b"\x07\xFE\x00\x03\xE0",
    b"\x07\xFE\x00\x03\xE0",
    b"\x07\xFE\x00\x03\xE0",
    b"\x07\xFE\x00\x03\xE0",
    b"\x07\xFE\x00\x7F\xE0",
    b"\x07\xFE\x00\x7F\xE0",
    b"\x07\xFE\x00\x7F\xE0",
    b"\x07\xFE\x00\x7F\xE0",
    b"\x07\xFE\x00\x7F\xE0",
    b"\x00\x00\x0F\xFC\x00",
    b"\x00\x00\x0F\xFC\x00",
    b"\x00\x00\x0F\xFC\x00",
    b"\x00\x00\x0F\xFC\x00",
    b"\x00\x00\x0F\xFC\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x07\xFE\x00\x7F\xE0",
    b"\x07\xFE\x00\x7F\xE0",
    b"\x07\xFE\x00\x7F\xE0",
    b"\x07\xFE\x00\x7F\xE0",
    b"\x07\xFE\x00\x7F\xE0",
    b"\xFF\xC0\x00\x7F\xE0",
    b"\xFF\xC0\x00\x7F\xE0",
    b"\xFF\xC0\x00\x7F\xE0",
    b"\xFF\xC0\x00\x7F\xE0",
    b"\xFF\xC0\x00\x7F\xE0",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
]

CHAR_AND = [
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x3F\xFF\x80\x00",
    b"\x00\x3F\xFF\x80\x00",
    b"\x00\x3F\xFF\x80\x00",
    b"\x00\x3F\xFF\x80\x00",
    b"\x00\x3F\xFF\x80\x00",
    b"\x07\xFE\x0F\xFC\x00",
    b"\x07\xFE\x0F\xFC\x00",
    b"\x07\xFE\x0F\xFC\x00",
    b"\x07\xFE\x0F\xFC\x00",
    b"\x07\xFE\x0F\xFC\x00",
    b"\x00\x3F\xFF\x83\xFF",
    b"\x00\x3F\xFF\x83\xFF",
    b"\x00\x3F\xFF\x83\xFF",
    b"\x00\x3F\xFF\x83\xFF",
    b"\x00\x3F\xFF\x83\xFF",
    b"\x07\xFE\x0F\xFF\xE0",
    b"\x07\xFE\x0F\xFF\xE0",
    b"\x07\xFE\x0F\xFF\xE0",
    b"\x07\xFE\x0F\xFF\xE0",
    b"\x07\xFE\x0F\xFF\xE0",
    b"\xFF\xC0\x00\x7F\xE0",
    b"\xFF\xC0\x00\x7F\xE0",
    b"\xFF\xC0\x00\x7F\xE0",
    b"\xFF\xC0\x00\x7F\xE0",
    b"\xFF\xC0\x00\x7F\xE0",
    b"\x07\xFF\xFF\x83\xFF",
    b"\x07\xFF\xFF\x83\xFF",
    b"\x07\xFF\xFF\x83\xFF",
    b"\x07\xFF\xFF\x83\xFF",
    b"\x07\xFF\xFF\x83\xFF",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
]

CHAR_LPAREN = [
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
]

CHAR_RPAREN = [
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
]

CHAR_DASH = [
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x07\xFF\xFF\xFF\xE0",
    b"\x07\xFF\xFF\xFF\xE0",
    b"\x07\xFF\xFF\xFF\xE0",
    b"\x07\xFF\xFF\xFF\xE0",
    b"\x07\xFF\xFF\xFF\xE0",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
]

CHAR_COLON = [
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
]

CHAR_SEMICOLON = [
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
]

CHAR_APOST = [
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
]

CHAR_QUOTE = [
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x3E\x00\x7C\x00",
    b"\x00\x3E\x00\x7C\x00",
    b"\x00\x3E\x00\x7C\x00",
    b"\x00\x3E\x00\x7C\x00",
    b"\x00\x3E\x00\x7C\x00",
    b"\x00\x3E\x00\x7C\x00",
    b"\x00\x3E\x00\x7C\x00",
    b"\x00\x3E\x00\x7C\x00",
    b"\x00\x3E\x00\x7C\x00",
    b"\x00\x3E\x00\x7C\x00",
    b"\x00\x3E\x00\x7C\x00",
    b"\x00\x3E\x00\x7C\x00",
    b"\x00\x3E\x00\x7C\x00",
    b"\x00\x3E\x00\x7C\x00",
    b"\x00\x3E\x00\x7C\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
]

CHAR_COMMA = [
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
]

CHAR_DOT = [
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
]

CHAR_QUESTION = [
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x3F\xFF\xFC\x00",
    b"\x00\x3F\xFF\xFC\x00",
    b"\x00\x3F\xFF\xFC\x00",
    b"\x00\x3F\xFF\xFC\x00",
    b"\x00\x3F\xFF\xFC\x00",
    b"\x07\xFE\x00\x7F\xE0",
    b"\x07\xFE\x00\x7F\xE0",
    b"\x07\xFE\x00\x7F\xE0",
    b"\x07\xFE\x00\x7F\xE0",
    b"\x07\xFE\x00\x7F\xE0",
    b"\x00\x00\x00\x7F\xE0",
    b"\x00\x00\x00\x7F\xE0",
    b"\x00\x00\x00\x7F\xE0",
    b"\x00\x00\x00\x7F\xE0",
    b"\x00\x00\x00\x7F\xE0",
    b"\x00\x01\xFF\xFC\x00",
    b"\x00\x01\xFF\xFC\x00",
    b"\x00\x01\xFF\xFC\x00",
    b"\x00\x01\xFF\xFC\x00",
    b"\x00\x01\xFF\xFC\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
]

CHAR_FORSLASH = [
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x0F\xFC\x00",
    b"\x00\x00\x0F\xFC\x00",
    b"\x00\x00\x0F\xFC\x00",
    b"\x00\x00\x0F\xFC\x00",
    b"\x00\x00\x0F\xFC\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x07\xFE\x00\x00\x00",
    b"\x07\xFE\x00\x00\x00",
    b"\x07\xFE\x00\x00\x00",
    b"\x07\xFE\x00\x00\x00",
    b"\x07\xFE\x00\x00\x00",
    b"\x07\xC0\x00\x00\x00",
    b"\x07\xC0\x00\x00\x00",
    b"\x07\xC0\x00\x00\x00",
    b"\x07\xC0\x00\x00\x00",
    b"\x07\xC0\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
]

CHAR_BACKSLASH = [
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x3F\xF0\x00\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x01\xFF\x80\x00",
    b"\x00\x00\x0F\xFC\x00",
    b"\x00\x00\x0F\xFC\x00",
    b"\x00\x00\x0F\xFC\x00",
    b"\x00\x00\x0F\xFC\x00",
    b"\x00\x00\x0F\xFC\x00",
    b"\x00\x00\x00\x7F\xE0",
    b"\x00\x00\x00\x7F\xE0",
    b"\x00\x00\x00\x7F\xE0",
    b"\x00\x00\x00\x7F\xE0",
    b"\x00\x00\x00\x7F\xE0",
    b"\x00\x00\x00\x03\xE0",
    b"\x00\x00\x00\x03\xE0",
    b"\x00\x00\x00\x03\xE0",
    b"\x00\x00\x00\x03\xE0",
    b"\x00\x00\x00\x03\xE0",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
]

CHAR_space = [
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
    b"\x00\x00\x00\x00\x00",
]

CHAR_NOT_FOUND = [
    b"\xFF\xFF\xFF\xFF\xFF",
    b"\xFF\xFF\xFF\xFF\xFF",
    b"\xFF\xFF\xFF\xFF\xFF",
    b"\xFF\xFF\xFF\xFF\xFF",
    b"\xFF\xFF\xFF\xFF\xFF",
    b"\xFF\xFE\x00\x7F\xFF",
    b"\xFF\xFE\x00\x7F\xFF",
    b"\xFF\xFE\x00\x7F\xFF",
    b"\xFF\xFE\x00\x7F\xFF",
    b"\xFF\xFE\x00\x7F\xFF",
    b"\xFF\xFF\xFF\xFF\xFF",
    b"\xFF\xFF\xFF\xFF\xFF",
    b"\xFF\xFF\xFF\xFF\xFF",
    b"\xFF\xFF\xFF\xFF\xFF",
    b"\xFF\xFF\xFF\xFF\xFF",
    b"\xFF\xC0\x00\x7F\xFF",
    b"\xFF\xC0\x00\x7F\xFF",
    b"\xFF\xC0\x00\x7F\xFF",
    b"\xFF\xC0\x00\x7F\xFF",
    b"\xFF\xC0\x00\x7F\xFF",
    b"\xF8\x01\xFF\xFF\xFF",
    b"\xF8\x01\xFF\xFF\xFF",
    b"\xF8\x01\xFF\xFF\xFF",
    b"\xF8\x01\xFF\xFF\xFF",
    b"\xF8\x01\xFF\xFF\xFF",
    b"\xF8\x01\xFF\x80\x1F",
    b"\xF8\x01\xFF\x80\x1F",
    b"\xF8\x01\xFF\x80\x1F",
    b"\xF8\x01\xFF\x80\x1F",
    b"\xF8\x01\xFF\x80\x1F",
    b"\xFF\xC0\x00\x03\xFF",
    b"\xFF\xC0\x00\x03\xFF",
    b"\xFF\xC0\x00\x03\xFF",
    b"\xFF\xC0\x00\x03\xFF",
    b"\xFF\xC0\x00\x03\xFF",
    b"\xFF\xFF\xFF\xFF\xFF",
    b"\xFF\xFF\xFF\xFF\xFF",
    b"\xFF\xFF\xFF\xFF\xFF",
    b"\xFF\xFF\xFF\xFF\xFF",
    b"\xFF\xFF\xFF\xFF\xFF",
]
